@@ -17,6 +17,7 @@ import sys
 from collections import namedtuple
 from enum import Enum
 from functools import wraps
+from pathlib import Path
 from typing import (
     Any,
     Callable,
@@ -26,6 +27,7 @@ from typing import (
 
 import commonmark
 import requests
+import toml
 from gql.transport.exceptions import TransportServerError
 from graphql import (
     GraphQLField,
@@ -34,10 +36,12 @@ from graphql import (
     GraphQLType,
 )
 from graphql.pyutils.undefined import UndefinedType
+from importlib_metadata import packages_distributions
 from packaging import version
 from qctrlcommons.exceptions import QctrlException
 from requests import codes
 from requests.exceptions import HTTPError
+from rich.console import Console
 
 from qctrl.constants import UNIVERSAL_ERROR_MESSAGE
 
@@ -249,11 +253,16 @@ class PackageRegistry(Enum):
         assert pkg is not None, f"{self.value.pkg_name} is not found."
         local_version = getattr(pkg, "__version__")
         if version.parse(local_version) < version.parse(latest_version):
-            print(f"{self.value.name} package update available.")
-            print(
-                f"Your version is {local_version}. Latest version is {latest_version}."
+            console = Console()
+            console.print(f"{self.value.name} package update available.")
+            console.print(
+                f"Your version is [bold cyan]{local_version}[/bold cyan]."
+                f" Latest version is [bold cyan]{latest_version}[/bold cyan]."
+            )
+            url = "boulder.q-ctrl.com/changelog"
+            console.print(
+                f"Visit [link=https://{url}]{url}[/link] for the latest product updates."
             )
-            print("Visit boulder.q-ctrl.com/changelog for the latest product updates.")
 
 
 def _get_latest_version(url) -> str:
@@ -324,7 +333,25 @@ def print_environment_related_packages():
     as a Markdown-formatted table.
     """
 
-    modules = [
+    # packages_distributions returns a map between the top-level module names and package names
+    # however, it doesn't understand packages installed in the editable mode,
+    # which is handled in _get_package_name
+    _package_names_mapping = packages_distributions()
+
+    def _get_package_name(module):
+        if module.__name__ in _package_names_mapping:
+            return _package_names_mapping[module.__name__][0]
+
+        # otherwise it's in the editable mode, looking for pyproject.toml to get the package name
+        with open(
+            Path.joinpath(Path(module.__path__[0]).parent, "pyproject.toml"),
+            mode="r",
+            encoding="utf-8",
+        ) as file:
+            config = toml.load(file)
+            return config["tool"]["poetry"]["name"]
+
+    top_level_module_names = [
         # External packages.
         "jsonpickle",
         "matplotlib",
@@ -336,8 +363,6 @@ def print_environment_related_packages():
         # Q-CTRL packages.
         "qctrl",
         "qctrlcommons",
-        "qctrlcore",
-        "qctrllocal",
         "qctrlmloop",
         "qctrlopencontrols",
         "qctrlpyquil",
@@ -346,23 +371,30 @@ def print_environment_related_packages():
         "qctrlvisualizer",
     ]
 
-    # Widths of the table columns.
-    package_width = max(len(name) for name in modules)
-    version_width = len("16.23.42rc4")
-
     python_version = (
         f"{sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}"
     )
 
     # List containing the items in the different rows.
     table_items = [
-        ("Package", "version"),
+        (
+            _get_package_name(sys.modules[module_name]),
+            sys.modules[module_name].__version__,
+        )
+        for module_name in top_level_module_names
+        if module_name in sys.modules
+    ]
+
+    # Widths of the table columns.
+    package_width = max(max(len(item[0]) for item in table_items), 7)
+    version_width = max(max(len(item[1]) for item in table_items), 7)
+
+    # Add headers and Python version at top of table.
+    table_items = [
+        ("Package", "Version"),
         ("-" * package_width, "-" * version_width),
         ("Python", python_version),
-    ]
-    table_items = table_items + [
-        (name, sys.modules[name].__version__) for name in modules if name in sys.modules
-    ]
+    ] + table_items
 
     # Print table.
     for name, version_ in table_items:
